@@ -16,7 +16,7 @@ from snakeoil.demandload import demand_compile_regexp
 from ..restrictions import boolean, packages, restriction, values
 from ..restrictions.packages import AndRestriction as PkgAndRestriction
 from ..restrictions.packages import Conditional
-from ..restrictions.values import ContainmentMatch2
+from ..restrictions.values import ContainmentMatch
 from . import cpv, errors, restricts
 
 # namespace compatibility...
@@ -446,8 +446,10 @@ class atom(boolean.AndRestriction, metaclass=klass.generic_equality):
 
         return cmp(self.repo_id, other.repo_id)
 
+    no_usedeps = klass.alias_attr("get_atom_without_use_deps")
+
     @property
-    def no_usedeps(self):
+    def get_atom_without_use_deps(self):
         """Return atom object stripped of USE dependencies."""
         if not self.use:
             return self
@@ -649,7 +651,7 @@ class transitive_use_atom(atom):
 
     @staticmethod
     def _mk_conditional(flag, payload, negate=False):
-        return Conditional('use', ContainmentMatch2(flag, negate=negate), payload)
+        return Conditional('use', ContainmentMatch(flag, negate=negate), payload)
 
     def _recurse_transitive_use_conds(self, atom_str, forced_use, varied):
         if not varied:
