@@ -786,6 +786,9 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
         sf(self, 'aliases', tuple(filter(None, iter_stable_unique(aliases))))
         sf(self, 'eapis_deprecated', tuple(iter_stable_unique(data.get('eapis-deprecated', '').split())))
         sf(self, 'eapis_banned', tuple(iter_stable_unique(data.get('eapis-banned', '').split())))
+        sf(self, 'eapis_testing', tuple(iter_stable_unique(data.get('eapis-testing', '').split())))
+        sf(self, 'profile_eapis_deprecated', tuple(iter_stable_unique(data.get('profile-eapis-deprecated', '').split())))
+        sf(self, 'profile_eapis_banned', tuple(iter_stable_unique(data.get('profile-eapis-banned', '').split())))
         sf(self, 'properties_allowed', tuple(iter_stable_unique(data.get('properties-allowed', '').split())))
         sf(self, 'restrict_allowed', tuple(iter_stable_unique(data.get('restrict-allowed', '').split())))
         sf(self, 'sign_commits', data.get('sign-commits', 'false').lower() == 'true')
@@ -883,7 +886,7 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
     def use_expand_desc(self):
         """USE_EXPAND settings for the repo."""
         base = pjoin(self.profiles_base, 'desc')
-        d = dict()
+        d = {}
         try:
             targets = listdir_files(base)
         except FileNotFoundError:
@@ -897,6 +900,24 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
 
         return mappings.ImmutableDict(d)
 
+    @klass.jit_attr
+    def use_expand_sort(self):
+        """Mapping of USE_EXPAND sorting keys for the repo."""
+        base = pjoin(self.profiles_base, 'desc')
+        d = {}
+        try:
+            targets = listdir_files(base)
+        except FileNotFoundError:
+            targets = []
+
+        for use_group in targets:
+            group = use_group.split('.', 1)[0]
+            use_expand = (x[0] for x in self._split_use_desc_file(
+                f'desc/{use_group}', lambda k: k, matcher=False))
+            d[group] = {use: i for i, use in enumerate(use_expand)}
+
+        return mappings.ImmutableDict(d)
+
     def _split_use_desc_file(self, name, converter, matcher=True):
         line = None
         fp = pjoin(self.profiles_base, name)
@@ -965,7 +986,7 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
     def updates(self):
         """Package updates for the repo defined in profiles/updates/*."""
         updates_dir = pjoin(self.profiles_base, 'updates')
-        d = pkg_updates.read_updates(updates_dir)
+        d = pkg_updates.read_updates(updates_dir, eapi=self.eapi)
         return mappings.ImmutableDict(d)
 
     @klass.jit_attr
