@@ -397,6 +397,14 @@ class UnconfiguredTree(prototype.tree):
             pass
         return ImmutableDict(mirrors)
 
+    @klass.jit_attr
+    def use_expand_desc(self):
+        """Inherited USE_EXPAND settings for the repo."""
+        d = {}
+        for repo in self.trees:
+            d.update(repo.config.use_expand_desc)
+        return ImmutableDict(d)
+
     @klass.jit_attr
     def use_expand_sort(self):
         """Inherited mapping of USE_EXPAND sorting keys for the repo."""
@@ -556,7 +564,10 @@ class UnconfiguredTree(prototype.tree):
     @klass.jit_attr
     def deprecated(self):
         """Base deprecated packages restriction from profiles/package.deprecated."""
-        return packages.OrRestriction(*self.config.pkg_deprecated)
+        pkg_deprecated = set()
+        for repo in self.trees:
+            pkg_deprecated.update(repo.config.pkg_deprecated)
+        return packages.OrRestriction(*pkg_deprecated)
 
     def _regen_operation_helper(self, **kwds):
         return _RegenOpHelper(
