@@ -7,10 +7,10 @@ __all__ = ("tree",)
 # icky.
 # ~harring
 
-from snakeoil.klass import GetAttrProxy, DirProxy
+from snakeoil.klass import DirProxy, GetAttrProxy
 
-from pkgcore.operations import repo
-from pkgcore.repository import prototype, errors
+from ..operations import repo
+from . import errors, prototype
 
 
 class tree(prototype.tree):
